models

package
v0.0.0-...-f98d395 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 6, 2023 License: MIT Imports: 0 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Password

type Password struct {
	ID           string `json:"id"`
	UserID       string `json:"userId"`
	PasswordHash string `json:"passwordHash"`
	CreatedAt    int64  `json:"createdAt"`
}

Password represents a single password in the system for a user. User can have multiple passwords, but only one active password.

Jump to