package
Version:
v0.0.0-...-f98d395
Opens a new window with list of versions in this module.
Published: Sep 6, 2023
License: MIT
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Password struct {
ID string `json:"id"`
UserID string `json:"userId"`
PasswordHash string `json:"passwordHash"`
CreatedAt int64 `json:"createdAt"`
}
Password represents a single password in the system for a user.
User can have multiple passwords, but only one active password.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.